diff --git a/README.txt b/README.txt
index 34224b7..ccd0d37 100644
--- a/README.txt
+++ b/README.txt
@@ -20,7 +20,7 @@
  * * Watchdog
  * * Cron execution
  * * Content and User activity
- * Sensor interface that can be easily implemented to provide custom sensors.
+ * SensorPlugin interface that can be easily implemented to provide custom sensors.
  * Integration with Munin.
  * Integration with Icinga/Nagios
 
@@ -50,6 +50,6 @@
  variable, for example in settings.php. This allows to enforce environment
  specific settings, like disabling a certain sensor.
 
- $conf['monitoring_sensor_info']['name_of_the_sensor']['settings']['enabled'] = FALSE;
+ $conf['monitoring_sensor']['name_of_the_sensor']['settings']['enabled'] = FALSE;
 
  Anything defined through the hook can be overridden.
diff --git a/config/install/views.view.monitoring_sensor_results.yml b/config/install/views.view.monitoring_sensor_results.yml
index 77c8253..55f0c6e 100644
--- a/config/install/views.view.monitoring_sensor_results.yml
+++ b/config/install/views.view.monitoring_sensor_results.yml
@@ -87,7 +87,7 @@ display:
           relationship: none
           group_type: group
           admin_label: ''
-          label: 'Sensor name'
+          label: 'SensorPlugin name'
           exclude: false
           alter:
             alter_text: false
diff --git a/config/schema/monitoring.schema.yml b/config/schema/monitoring.schema.yml
index f6910fa..9068250 100644
--- a/config/schema/monitoring.schema.yml
+++ b/config/schema/monitoring.schema.yml
@@ -2,7 +2,7 @@
 
 monitoring.sensor_config.*:
   type: config_entity
-  label: 'Monitoring Sensor'
+  label: 'Monitoring SensorPlugin'
   mapping:
     id:
       type: string
@@ -18,7 +18,7 @@ monitoring.sensor_config.*:
       label: 'Category'
     sensor_id:
       type: string
-      label: 'Sensor ID'
+      label: 'SensorPlugin ID'
     result_class:
       type: string
       label: 'Result Class'
@@ -40,7 +40,7 @@ monitoring.sensor_config.*:
 
 monitoring.settings.monitoring_git_dirty_tree:
   type: mapping
-  label: 'Sensor settings'
+  label: 'SensorPlugin settings'
   mapping:
     repo_path:
       type: string
diff --git a/config/schema/monitoring.views.schema.yml b/config/schema/monitoring.views.schema.yml
index fdd708a..77869af 100644
--- a/config/schema/monitoring.views.schema.yml
+++ b/config/schema/monitoring.views.schema.yml
@@ -2,4 +2,4 @@
 
 views.field.monitoring_sensor_name:
   type: views_field
-  label: 'Sensor name'
+  label: 'SensorPlugin name'
diff --git a/modules/demo/monitoring_demo.install b/modules/demo/monitoring_demo.install
index 5b088a1..a0ee536 100644
--- a/modules/demo/monitoring_demo.install
+++ b/modules/demo/monitoring_demo.install
@@ -19,7 +19,7 @@ function monitoring_demo_install() {
 
   // Enable REST API for monitoring resources.
   $settings = array(
-    'monitoring-sensor-info' => array(
+    'monitoring-sensor' => array(
       'GET' => array(
         'supported_formats' => array('hal_json'),
         'supported_auth' => array('cookie'),
diff --git a/modules/demo/src/Controller/FrontPage.php b/modules/demo/src/Controller/FrontPage.php
index 430e341..25e5e02 100644
--- a/modules/demo/src/Controller/FrontPage.php
+++ b/modules/demo/src/Controller/FrontPage.php
@@ -61,8 +61,8 @@ class FrontPage extends ControllerBase {
         'list' => array(
           '#theme' => 'item_list',
           '#items' => array(
-            t('Drush integration - open up your console and type in # drush monitoring-info or # drush monitoring-run. See the drush help for more info and commands.'),
-            t('REST resource for both the info about sensors and running the sensors via the service. Open up your REST client and visit /monitoring-sensor-info/{sensor_name} and /monitoring-sensor-result/{sensor_name}'),
+            t('Drush integration - open up your console and type in # drush monitoring-sensor or # drush monitoring-run. See the drush help for more info and commands.'),
+            t('REST resource for both the info about sensors and running the sensors via the service. Open up your REST client and visit /monitoring-sensor/{sensor_name} and /monitoring-sensor-result/{sensor_name}'),
           )
         ),
       ),
diff --git a/modules/monitoring_icinga/monitoring_icinga.module b/modules/monitoring_icinga/monitoring_icinga.module
index 7b93da3..a1082e9 100644
--- a/modules/monitoring_icinga/monitoring_icinga.module
+++ b/modules/monitoring_icinga/monitoring_icinga.module
@@ -44,7 +44,7 @@ function monitoring_icinga_menu() {
  * submitting passive check.
  *
  * @param SensorConfig $sensor_config
- *   Sensor config object.
+ *   SensorPlugin config object.
  *
  * @return string
  *   Icinga service description.
diff --git a/modules/multigraph/src/Form/MultigraphForm.php b/modules/multigraph/src/Form/MultigraphForm.php
index 72f0301..2af899a 100644
--- a/modules/multigraph/src/Form/MultigraphForm.php
+++ b/modules/multigraph/src/Form/MultigraphForm.php
@@ -220,7 +220,7 @@ class MultigraphForm extends EntityForm {
     if ($sensor_name = $form_state->getValue(array('sensor_add', 'sensor_add_select'))) {
       $sensor_label = \Drupal::entityManager()->getStorage('monitoring_sensor_config')->load($sensor_name)->getLabel();
       $multigraph->addSensor($sensor_name);
-      drupal_set_message($this->t('Sensor "@sensor_label" added. You have unsaved changes.', array('@sensor_label' => $sensor_label)), 'warning');
+      drupal_set_message($this->t('SensorPlugin "@sensor_label" added. You have unsaved changes.', array('@sensor_label' => $sensor_label)), 'warning');
     }
   }
 
diff --git a/modules/multigraph/src/Tests/MultigraphServicesTest.php b/modules/multigraph/src/Tests/MultigraphServicesTest.php
index 7cc2ac8..9452124 100644
--- a/modules/multigraph/src/Tests/MultigraphServicesTest.php
+++ b/modules/multigraph/src/Tests/MultigraphServicesTest.php
@@ -87,7 +87,7 @@ class MultigraphServicesTest extends RESTTestBase {
 
     // Test response for non-existing multigraph.
     $name = 'multigraph_that_does_not_exist';
-    $this->doRequest('monitoring-sensor-info/' . $name);
+    $this->doRequest('monitoring-sensor/' . $name);
     $this->assertResponse(404);
 
     // Test the predefined multigraph.
diff --git a/modules/test/config/install/monitoring.sensor_config.test_sensor_info.yml b/modules/test/config/install/monitoring.sensor_config.test_sensor_info.yml
index 62c7f63..c85868d 100644
--- a/modules/test/config/install/monitoring.sensor_config.test_sensor_info.yml
+++ b/modules/test/config/install/monitoring.sensor_config.test_sensor_info.yml
@@ -5,4 +5,3 @@ sensor_id: test_sensor
 value_type: 'number'
 value_label: 'Test label'
 settings:
-
diff --git a/modules/test/src/Plugin/monitoring/Sensor/TestSensor.php b/modules/test/src/Plugin/monitoring/SensorPlugin/TestSensorPlugin.php
similarity index 85%
rename from modules/test/src/Plugin/monitoring/Sensor/TestSensor.php
rename to modules/test/src/Plugin/monitoring/SensorPlugin/TestSensorPlugin.php
index 00b3a97..a6106c3 100644
--- a/modules/test/src/Plugin/monitoring/Sensor/TestSensor.php
+++ b/modules/test/src/Plugin/monitoring/SensorPlugin/TestSensorPlugin.php
@@ -1,28 +1,28 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring_test\Plugin\monitoring\Sensor\TestSensor.
+ * Contains \Drupal\monitoring_test\Plugin\monitoring\SensorPlugin\TestSensorPlugin.
  */
 
-namespace Drupal\monitoring_test\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring_test\Plugin\monitoring\SensorPlugin;
 
-use Drupal\monitoring\Sensor\SensorExtendedInfoInterface;
+use Drupal\monitoring\SensorPlugin\ExtendedInfoSensorPluginInterface;
 use Drupal\monitoring\Entity\SensorConfig;
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\ThresholdsSensorBase;
+use Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginBase;
 
 /**
  * Test sensor to report status as provided by external arguments.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "test_sensor",
- *   label = @Translation("Test Sensor"),
+ *   label = @Translation("Test SensorPlugin"),
  *   description = @Translation("Test sensor to report status as provided by external arguments."),
  *   addable = TRUE
  * )
  *
  */
-class TestSensor extends ThresholdsSensorBase implements SensorExtendedInfoInterface {
+class TestSensorPlugin extends ThresholdsSensorPluginBase implements ExtendedInfoSensorPluginInterface {
 
   protected $testSensorResultData;
 
diff --git a/monitoring.api.php b/monitoring.api.php
index 18a4894..a91b287 100644
--- a/monitoring.api.php
+++ b/monitoring.api.php
@@ -13,7 +13,7 @@ use Drupal\monitoring\Result\SensorResultInterface;
  * @param array $links
  *   Links to be altered.
  * @param \Drupal\monitoring\Entity\SensorConfig $sensor_config
- *   Sensor config object of a sensor for which links are being altered.
+ *   SensorPlugin config object of a sensor for which links are being altered.
  *
  * @see monitoring_reports_sensors_overview()
  */
diff --git a/monitoring.drush.inc b/monitoring.drush.inc
index 153da80..a9d3533 100644
--- a/monitoring.drush.inc
+++ b/monitoring.drush.inc
@@ -64,7 +64,7 @@ function monitoring_drush_command() {
       'verbose' => 'Display verbose information.',
       'force' => 'If the sensor execution should be forced in case cached result is available.',
       'output' => 'The output format. Currently "table" and "json" available. Defaults to "table".',
-      'expand' => 'Relevant only for the json output. Currently "sensor_info" value supported.',
+      'expand' => 'Relevant only for the json output. Currently "sensor" value supported.',
       'show-exec-time' => 'Relevant for the table output listing all results. Will expand the table with execution time info.'
     ),
     'examples' => array(
@@ -259,9 +259,10 @@ function monitoring_drush_run($sensor_name = NULL) {
 function monitoring_drush_result_output_json(array $results, $expand = NULL) {
   $json_output = array();
   foreach ($results as $result) {
-    $json_output[$result->getSensorName()] = $result->toArray();
-    if ($expand == 'sensor_info') {
-      $json_output[$result->getSensorName()]['sensor_info'] = $result->getSensorConfig()->toArray();
+    $sensor_name = $result->getSensorName();
+    $json_output[$sensor_name] = $result->toArray();
+    if ($expand == 'sensor') {
+      $json_output[$sensor_name]['sensor'] = $result->getSensorConfig()->toArray();
     }
   }
   drush_print(Json::encode($json_output));
diff --git a/monitoring.monitoring_sensors.inc b/monitoring.monitoring_sensors.inc
index 59bd055..3be8bb4 100644
--- a/monitoring.monitoring_sensors.inc
+++ b/monitoring.monitoring_sensors.inc
@@ -4,23 +4,23 @@
  * Define default sensors for core and contrib modules.
  *
  * Default sensors provide sensors for core and contrib modules with
- * monitoring_MODULE_monitoring_sensor_info()
+ * monitoring_MODULE_monitoring_sensor()
  *
  * The default integration for MODULE is omitted if a module implements
  * hook_monitoring_sensor_info() on its own.
  *
- * @see hook_monitoring_sensor_info()
+ * @see hook_monitoring_sensor()
  */
 
 use Drupal\Component\Utility\String;
 
 /**
- * Implements monitoring_MODULE_monitoring_sensor_info().
+ * Implements monitoring_MODULE_monitoring_sensor().
  *
  * @todo-Convert below sensors to config entities after these modules are ported in 8.x
  * Module: past_db
  */
-function monitoring_past_db_monitoring_sensor_info() {
+function monitoring_past_db_monitoring_sensor() {
   $info = array();
   $severities = monitoring_event_severities();
 
@@ -55,11 +55,11 @@ function monitoring_past_db_monitoring_sensor_info() {
 }
 
 /**
- * Implements monitoring_MODULE_monitoring_sensor_info().
+ * Implements monitoring_MODULE_monitoring_sensor().
  *
  * Module: elysia_cron
  */
-function monitoring_elysia_cron_monitoring_sensor_info() {
+function monitoring_elysia_cron_monitoring_sensor() {
   $info = array();
 
   $result = db_select('elysia_cron', 'e')->fields('e', array('name'))->execute()->fetchAll();
@@ -97,11 +97,11 @@ function monitoring_elysia_cron_monitoring_sensor_info() {
 }
 
 /**
- * Implements monitoring_MODULE_monitoring_sensor_info().
+ * Implements monitoring_MODULE_monitoring_sensor().
  *
  * Module: commerce_order
  */
-function monitoring_commerce_order_monitoring_sensor_info() {
+function monitoring_commerce_order_monitoring_sensor() {
   $info = array();
 
   // Expose a sensor for each order status, disabled by default.
diff --git a/monitoring.routing.yml b/monitoring.routing.yml
index ecc9e14..81ab879 100644
--- a/monitoring.routing.yml
+++ b/monitoring.routing.yml
@@ -25,14 +25,14 @@ monitoring.detail_form:
 monitoring.force_run_all:
   path: 'monitoring/sensors/force'
   defaults:
-    _controller: '\Drupal\monitoring\Controller\ForceRunController::forceRunAll'
+    _controller: '\Drupal\monitoring\Controller\SensorForceRunController::forceRunAll'
   requirements:
     _permission: 'monitoring force run'
 
 monitoring.force_run_sensor:
   path: 'monitoring/sensors/force/{monitoring_sensor_config}'
   defaults:
-    _controller: '\Drupal\monitoring\Controller\ForceRunController::forceRunSensor'
+    _controller: '\Drupal\monitoring\Controller\SensorForceRunController::forceRunSensor'
   requirements:
     _permission: 'monitoring force run'
 
@@ -63,6 +63,6 @@ monitoring.sensor_add:
 monitoring.config_autocomplete:
   path: '/monitoring-config/autocomplete'
   defaults:
-    _controller: '\Drupal\monitoring\Controller\ConfigAutocompleteController::autocomplete'
+    _controller: '\Drupal\monitoring\Controller\SensorConfigAutocompleteController::autocomplete'
   requirements:
     _permission: 'administer monitoring'
diff --git a/review.txt b/review.txt
index 23c4918..916ece9 100644
--- a/review.txt
+++ b/review.txt
@@ -1,2 +1,2 @@
 - Wondering if we should add a SensorConfig::getSensor() (factory to create a sensor based on getSensorClass()), to a) solve the type hint problem and b), support container service injection like plugins with the create() method. See ContainerFactory, you would just inline that logic. Advantage: Easier to convert to plugins later.
-- the status message in CronLastRunAgeSensor is now almost duplicated due to the value type formatting, but that's an existing problem in 7.x.
+- the status message in CronLastRunAgeSensorPlugin is now almost duplicated due to the value type formatting, but that's an existing problem in 7.x.
diff --git a/src/Controller/ConfigAutocompleteController.php b/src/Controller/SensorConfigAutocompleteController.php
similarity index 80%
rename from src/Controller/ConfigAutocompleteController.php
rename to src/Controller/SensorConfigAutocompleteController.php
index 4b87343..0a3cfc0 100644
--- a/src/Controller/ConfigAutocompleteController.php
+++ b/src/Controller/SensorConfigAutocompleteController.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\monitoring\Controller\ConfigAutocompleteController.
+ * Contains \Drupal\monitoring\Controller\SensorConfigAutocompleteController.
  */
 
 namespace Drupal\monitoring\Controller;
@@ -14,12 +14,12 @@ use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
 
 /**
- * Returns autocomplete responses for config.
+ * Returns auto complete responses for config.
  */
-class ConfigAutocompleteController {
+class SensorConfigAutocompleteController {
 
   /**
-   * Retrieves suggestions for config autocompletion.
+   * Retrieves suggestions for config auto completion.
    *
    * @param \Symfony\Component\HttpFoundation\Request $request
    *   The current request.
diff --git a/src/Controller/ForceRunController.php b/src/Controller/SensorForceRunController.php
similarity index 97%
rename from src/Controller/ForceRunController.php
rename to src/Controller/SensorForceRunController.php
index 257915a..8be792a 100644
--- a/src/Controller/ForceRunController.php
+++ b/src/Controller/SensorForceRunController.php
@@ -10,7 +10,7 @@ use Drupal\monitoring\SensorRunner;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 
-class ForceRunController extends ControllerBase {
+class SensorForceRunController extends ControllerBase {
 
   /**
    * Stores the sensor manager.
diff --git a/src/Controller/SensorList.php b/src/Controller/SensorList.php
index 7510e49..fb4a2a0 100644
--- a/src/Controller/SensorList.php
+++ b/src/Controller/SensorList.php
@@ -4,6 +4,7 @@ namespace Drupal\monitoring\Controller;
 
 use Drupal\Component\Utility\Unicode;
 use Drupal\Core\Controller\ControllerBase;
+use Drupal\monitoring\Entity\SensorConfig;
 use Drupal\monitoring\Result\SensorResultInterface;
 use Drupal\monitoring\Sensor\SensorManager;
 use Drupal\monitoring\SensorRunner;
@@ -66,7 +67,7 @@ class SensorList extends ControllerBase {
     // Oldest sensor config.
     $oldest_sensor_config = NULL;
 
-    foreach ($this->sensorManager->getSensorConfigByCategories() as $category => $category_sensor_info) {
+    foreach ($this->sensorManager->getSensorConfigByCategories() as $category => $category_sensor_config) {
 
       // Category grouping row.
       $rows[] = array(
@@ -79,7 +80,8 @@ class SensorList extends ControllerBase {
       );
       $ok_row_count = 0;
 
-      foreach ($category_sensor_info as $sensor_name => $sensor_config) {
+      /** @var SensorConfig $sensor_config */
+      foreach ($category_sensor_config as $sensor_name => $sensor_config) {
         if (!isset($results[$sensor_name])) {
           continue;
         }
diff --git a/src/Entity/SensorResultEntity.php b/src/Entity/SensorResultEntity.php
index 0e7d5fb..f206503 100644
--- a/src/Entity/SensorResultEntity.php
+++ b/src/Entity/SensorResultEntity.php
@@ -7,7 +7,6 @@
 namespace Drupal\monitoring\Entity;
 
 use Drupal\Core\Entity\ContentEntityBase;
-use Drupal\Core\Entity\EntityStorageInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Drupal\Core\Field\BaseFieldDefinition;
 
diff --git a/src/Form/SensorDetailForm.php b/src/Form/SensorDetailForm.php
index af6d8ef..3ae4429 100644
--- a/src/Form/SensorDetailForm.php
+++ b/src/Form/SensorDetailForm.php
@@ -79,7 +79,7 @@ class SensorDetailForm extends EntityForm {
     }
 
     if ($sensor_config->getDescription()) {
-      $form['sensor_info']['description'] = array(
+      $form['sensor_config']['description'] = array(
         '#type' => 'item',
         '#title' => $this->t('Description'),
         '#markup' => $sensor_config->getDescription(),
@@ -87,7 +87,7 @@ class SensorDetailForm extends EntityForm {
     }
 
     if ($sensor_config->getCategory()) {
-      $form['sensor_info']['category'] = array(
+      $form['sensor_config']['category'] = array(
         '#type' => 'item',
         '#title' => $this->t('Category'),
         '#markup' => $sensor_config->getCategory(),
diff --git a/src/Plugin/monitoring/Sensor/CommerceTurnoverSensor.php b/src/Plugin/monitoring/SensorPlugin/CommerceTurnoverSensorPlugin.php
similarity index 93%
rename from src/Plugin/monitoring/Sensor/CommerceTurnoverSensor.php
rename to src/Plugin/monitoring/SensorPlugin/CommerceTurnoverSensorPlugin.php
index 89d58c6..936c02c 100644
--- a/src/Plugin/monitoring/Sensor/CommerceTurnoverSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/CommerceTurnoverSensorPlugin.php
@@ -1,10 +1,11 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\CommerceTurnoverSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\CommerceTurnoverSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
+
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\monitoring\Result\SensorResultInterface;
 
@@ -13,7 +14,7 @@ use Drupal\monitoring\Result\SensorResultInterface;
  *
  * Based on SensorEntityDatabaseAggregator using commerce_order table.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "commerce_turnover",
  *   label = @Translation("Commerce order turnover"),
  *   description = @Translation("Monitors how much money was earned with commerce orders."),
@@ -22,7 +23,7 @@ use Drupal\monitoring\Result\SensorResultInterface;
  * )
  *
  */
-class CommerceTurnoverSensor extends EntityAggregatorSensor {
+class CommerceTurnoverSensorPlugin extends EntityAggregatorSensorPlugin {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/ConfigValueSensor.php b/src/Plugin/monitoring/SensorPlugin/ConfigValueSensorPlugin.php
similarity index 87%
rename from src/Plugin/monitoring/Sensor/ConfigValueSensor.php
rename to src/Plugin/monitoring/SensorPlugin/ConfigValueSensorPlugin.php
index 54c7b76..f415452 100644
--- a/src/Plugin/monitoring/Sensor/ConfigValueSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/ConfigValueSensorPlugin.php
@@ -2,25 +2,25 @@
 
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\ConfigValueSensor
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\ConfigValueSensorPlugin
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\Core\Form\FormStateInterface;
-use Drupal\monitoring\Sensor\ValueComparisonSensorBase;
+use Drupal\monitoring\SensorPlugin\ValueComparisonSensorPluginBase;
 
 /**
  * Generic sensor that checks for a configuration value.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "config_value",
  *   label = @Translation("Config Value"),
  *   description = @Translation("Checks for a specific configuration value."),
  *   addable = TRUE
  * )
  */
-class ConfigValueSensor extends ValueComparisonSensorBase {
+class ConfigValueSensorPlugin extends ValueComparisonSensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/CoreRequirementsSensor.php b/src/Plugin/monitoring/SensorPlugin/CoreRequirementsSensorPlugin.php
similarity index 93%
rename from src/Plugin/monitoring/Sensor/CoreRequirementsSensor.php
rename to src/Plugin/monitoring/SensorPlugin/CoreRequirementsSensorPlugin.php
index 9afbddf..dafb893 100644
--- a/src/Plugin/monitoring/Sensor/CoreRequirementsSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/CoreRequirementsSensorPlugin.php
@@ -1,20 +1,20 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\CoreRequirementsSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\CoreRequirementsSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\Component\Utility\String;
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\SensorBase;
+use Drupal\monitoring\SensorPlugin\SensorPluginBase;
 use Drupal\Core\Entity\DependencyTrait;
 
 /**
  * Monitors a specific module hook_requirements.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "core_requirements",
  *   label = @Translation("Core Requirements"),
  *   description = @Translation("Monitors a specific module hook_requirements."),
@@ -23,7 +23,7 @@ use Drupal\Core\Entity\DependencyTrait;
  *
  * @todo Shorten sensor message and add improved verbose output.
  */
-class CoreRequirementsSensor extends SensorBase {
+class CoreRequirementsSensorPlugin extends SensorPluginBase {
 
   use DependencyTrait;
 
diff --git a/src/Plugin/monitoring/Sensor/CronLastRunAgeSensor.php b/src/Plugin/monitoring/SensorPlugin/CronLastRunAgeSensorPlugin.php
similarity index 70%
rename from src/Plugin/monitoring/Sensor/CronLastRunAgeSensor.php
rename to src/Plugin/monitoring/SensorPlugin/CronLastRunAgeSensorPlugin.php
index f59d902..a33951c 100644
--- a/src/Plugin/monitoring/Sensor/CronLastRunAgeSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/CronLastRunAgeSensorPlugin.php
@@ -1,19 +1,19 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\CronLastRunAgeSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\CronLastRunAgeSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
-use Drupal\monitoring\Sensor\ThresholdsSensorBase;
+use Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginBase;
 use Drupal\monitoring\Result\SensorResultInterface;
 use Drupal;
 
 /**
  * Monitors the last cron run time.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "cron_last_run_time",
  *   label = @Translation("Cron Last Run Age"),
  *   description = @Translation("Monitors the last cron run time."),
@@ -22,7 +22,7 @@ use Drupal;
  *
  * Based on the drupal core system state cron_last.
  */
-class CronLastRunAgeSensor extends ThresholdsSensorBase {
+class CronLastRunAgeSensorPlugin extends ThresholdsSensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/DatabaseAggregatorSensor.php b/src/Plugin/monitoring/SensorPlugin/DatabaseAggregatorSensorPlugin.php
similarity index 90%
rename from src/Plugin/monitoring/Sensor/DatabaseAggregatorSensor.php
rename to src/Plugin/monitoring/SensorPlugin/DatabaseAggregatorSensorPlugin.php
index 5b506c0..523e224 100644
--- a/src/Plugin/monitoring/Sensor/DatabaseAggregatorSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/DatabaseAggregatorSensorPlugin.php
@@ -1,22 +1,22 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\DatabaseAggregatorSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\DatabaseAggregatorSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\Core\Database\Query\SelectInterface;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\SensorExtendedInfoInterface;
-use Drupal\monitoring\Sensor\DatabaseAggregatorSensorBase;
+use Drupal\monitoring\SensorPlugin\ExtendedInfoSensorPluginInterface;
+use Drupal\monitoring\SensorPlugin\DatabaseAggregatorSensorPluginBase;
 use Drupal\Core\Entity\DependencyTrait;
 
 /**
  * Simple database aggregator able to query a single db table.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "database_aggregator",
  *   label = @Translation("Simple Database Aggregator"),
  *   description = @Translation("Simple database aggregator able to query a single db table."),
@@ -24,7 +24,7 @@ use Drupal\Core\Entity\DependencyTrait;
  * )
  *
  */
-class DatabaseAggregatorSensor extends DatabaseAggregatorSensorBase implements SensorExtendedInfoInterface {
+class DatabaseAggregatorSensorPlugin extends DatabaseAggregatorSensorPluginBase implements ExtendedInfoSensorPluginInterface {
 
   use DependencyTrait;
 
diff --git a/src/Plugin/monitoring/Sensor/Dblog404Sensor.php b/src/Plugin/monitoring/SensorPlugin/Dblog404SensorPlugin.php
similarity index 81%
rename from src/Plugin/monitoring/Sensor/Dblog404Sensor.php
rename to src/Plugin/monitoring/SensorPlugin/Dblog404SensorPlugin.php
index 45ca09b..daed921 100644
--- a/src/Plugin/monitoring/Sensor/Dblog404Sensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/Dblog404SensorPlugin.php
@@ -1,17 +1,17 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\Dblog404Sensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\Dblog404SensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
 
 /**
  * Monitors 404 page errors from dblog.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "dblog_404",
  *   provider = "dblog",
  *   label = @Translation("404 page errors (database log)"),
@@ -21,7 +21,7 @@ use Drupal\monitoring\Result\SensorResultInterface;
  *
  * Displays URL with highest occurrence as message.
  */
-class Dblog404Sensor extends DatabaseAggregatorSensor {
+class Dblog404SensorPlugin extends DatabaseAggregatorSensorPlugin {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/DisappearedSensorsSensor.php b/src/Plugin/monitoring/SensorPlugin/DisappearedSensorsSensorPlugin.php
similarity index 94%
rename from src/Plugin/monitoring/Sensor/DisappearedSensorsSensor.php
rename to src/Plugin/monitoring/SensorPlugin/DisappearedSensorsSensorPlugin.php
index 175a454..535f0ae 100644
--- a/src/Plugin/monitoring/Sensor/DisappearedSensorsSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/DisappearedSensorsSensorPlugin.php
@@ -1,19 +1,19 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\DisappearedSensorsSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\DisappearedSensorsSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\SensorBase;
+use Drupal\monitoring\SensorPlugin\SensorPluginBase;
 
 /**
  * Monitors if sensors disappeared without prior being disabled.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "monitoring_disappeared_sensors",
  *   label = @Translation("Disappeared Sensors"),
  *   description = @Translation("Monitors if sensors disappeared without prior being disabled."),
@@ -24,7 +24,7 @@ use Drupal\monitoring\Sensor\SensorBase;
  * and compares it to the current sensor config retrieved via
  * monitoring_sensor_config() callback.
  */
-class DisappearedSensorsSensor extends SensorBase {
+class DisappearedSensorsSensorPlugin extends SensorPluginBase {
 
   /**
    * {@inheritdoc}
@@ -59,7 +59,7 @@ class DisappearedSensorsSensor extends SensorBase {
       );
       $form['clear_missing_sensors_wrapper']['info'] = array(
         '#type' => 'item',
-        '#title' => t('Sensor message'),
+        '#title' => t('SensorPlugin message'),
         '#markup' => $result->getMessage(),
       );
       $form['clear_missing_sensors_wrapper']['clear_missing_sensor'] = array(
diff --git a/src/Plugin/monitoring/Sensor/ElysiaCronSensor.php b/src/Plugin/monitoring/SensorPlugin/ElysiaCronSensorPlugin.php
similarity index 80%
rename from src/Plugin/monitoring/Sensor/ElysiaCronSensor.php
rename to src/Plugin/monitoring/SensorPlugin/ElysiaCronSensorPlugin.php
index 052fcd7..85f9643 100644
--- a/src/Plugin/monitoring/Sensor/ElysiaCronSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/ElysiaCronSensorPlugin.php
@@ -1,18 +1,18 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\ElysiaCronSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\ElysiaCronSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\ThresholdsSensorBase;
+use Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginBase;
 
 /**
  * Monitors elysia cron channels for last execution.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "elysia_cron",
  *   label = @Translation("Elysia Cron"),
  *   description = @Translation("Monitors elysia cron channels for last execution."),
@@ -21,7 +21,7 @@ use Drupal\monitoring\Sensor\ThresholdsSensorBase;
  * )
  *
  */
-class ElysiaCronSensor extends ThresholdsSensorBase {
+class ElysiaCronSensorPlugin extends ThresholdsSensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/EnabledModulesSensor.php b/src/Plugin/monitoring/SensorPlugin/EnabledModulesSensorPlugin.php
similarity index 96%
rename from src/Plugin/monitoring/Sensor/EnabledModulesSensor.php
rename to src/Plugin/monitoring/SensorPlugin/EnabledModulesSensorPlugin.php
index 05be6d3..24060ab 100644
--- a/src/Plugin/monitoring/Sensor/EnabledModulesSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/EnabledModulesSensorPlugin.php
@@ -1,21 +1,21 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\EnabledModulesSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\EnabledModulesSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\Component\Utility\String;
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\SensorBase;
+use Drupal\monitoring\SensorPlugin\SensorPluginBase;
 use Drupal;
 use Drupal\Core\Form\FormStateInterface;
 
 /**
  * Monitors installed modules.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "monitoring_enabled_modules",
  *   label = @Translation("Enabled Modules"),
  *   description = @Translation("Monitors installed modules."),
@@ -23,8 +23,7 @@ use Drupal\Core\Form\FormStateInterface;
  * )
  *
  */
-class EnabledModulesSensor extends SensorBase {
-
+class EnabledModulesSensorPlugin extends SensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/EntityAggregatorSensor.php b/src/Plugin/monitoring/SensorPlugin/EntityAggregatorSensorPlugin.php
similarity index 92%
rename from src/Plugin/monitoring/Sensor/EntityAggregatorSensor.php
rename to src/Plugin/monitoring/SensorPlugin/EntityAggregatorSensorPlugin.php
index 12ff770..aa88353 100644
--- a/src/Plugin/monitoring/Sensor/EntityAggregatorSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/EntityAggregatorSensorPlugin.php
@@ -1,16 +1,16 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\EntityAggregatorSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\EntityAggregatorSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\Component\Utility\String;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\SensorExtendedInfoInterface;
-use Drupal\monitoring\Sensor\DatabaseAggregatorSensorBase;
+use Drupal\monitoring\SensorPlugin\ExtendedInfoSensorPluginInterface;
+use Drupal\monitoring\SensorPlugin\DatabaseAggregatorSensorPluginBase;
 use Drupal\Core\DependencyInjection\DependencySerializationTrait;
 use Drupal\Core\Entity\DependencyTrait;
 use Drupal\Core\Entity\EntityManagerInterface;
@@ -23,14 +23,14 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  *
  * It utilises the entity query aggregate functionality.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "entity_aggregator",
  *   label = @Translation("Entity Aggregator"),
  *   description = @Translation("Utilises the entity query aggregate functionality."),
  *   addable = TRUE
  * )
  */
-class EntityAggregatorSensor extends DatabaseAggregatorSensorBase implements SensorExtendedInfoInterface {
+class EntityAggregatorSensorPlugin extends DatabaseAggregatorSensorPluginBase implements ExtendedInfoSensorPluginInterface {
 
   use DependencySerializationTrait;
   use DependencyTrait;
@@ -144,7 +144,7 @@ class EntityAggregatorSensor extends DatabaseAggregatorSensorBase implements Sen
   public function calculateDependencies() {
     $entity_type_id = $this->getEntityType();
     if (!$entity_type_id) {
-      throw new \Exception(String::format('Sensor @id is missing the required entity_type setting.', array('@id' => $this->id())));
+      throw new \Exception(String::format('SensorPlugin @id is missing the required entity_type setting.', array('@id' => $this->id())));
     }
     $entity_type = $this->entityManager->getDefinition($entity_type_id);
     $this->addDependency('module', $entity_type->getProvider());
diff --git a/src/Plugin/monitoring/Sensor/GitDirtyTreeSensor.php b/src/Plugin/monitoring/SensorPlugin/GitDirtyTreeSensorPlugin.php
similarity index 81%
rename from src/Plugin/monitoring/Sensor/GitDirtyTreeSensor.php
rename to src/Plugin/monitoring/SensorPlugin/GitDirtyTreeSensorPlugin.php
index c6e0d69..09c6b04 100644
--- a/src/Plugin/monitoring/Sensor/GitDirtyTreeSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/GitDirtyTreeSensorPlugin.php
@@ -1,19 +1,19 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\GitDirtyTreeSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\GitDirtyTreeSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\SensorBase;
-use Drupal\monitoring\Sensor\SensorExtendedInfoInterface;
+use Drupal\monitoring\SensorPlugin\SensorPluginBase;
+use Drupal\monitoring\SensorPlugin\ExtendedInfoSensorPluginInterface;
 
 /**
  * Monitors the git repository for dirty files.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "monitoring_git_dirty_tree",
  *   label = @Translation("Git Dirty Tree"),
  *   description = @Translation("Monitors the git repository for dirty files."),
@@ -27,7 +27,7 @@ use Drupal\monitoring\Sensor\SensorExtendedInfoInterface;
  * - Does not work as long as submodules are not initialized.
  * - Does not check branch / tag.
  */
-class GitDirtyTreeSensor extends SensorBase implements SensorExtendedInfoInterface {
+class GitDirtyTreeSensorPlugin extends SensorPluginBase implements ExtendedInfoSensorPluginInterface {
 
   /**
    * The executed command output.
diff --git a/src/Plugin/monitoring/Sensor/ImageMissingStyleSensor.php b/src/Plugin/monitoring/SensorPlugin/ImageMissingStyleSensorPlugin.php
similarity index 90%
rename from src/Plugin/monitoring/Sensor/ImageMissingStyleSensor.php
rename to src/Plugin/monitoring/SensorPlugin/ImageMissingStyleSensorPlugin.php
index f62ad42..05c3fb3 100644
--- a/src/Plugin/monitoring/Sensor/ImageMissingStyleSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/ImageMissingStyleSensorPlugin.php
@@ -1,10 +1,10 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\ImageMissingStyleSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\ImageMissingStyleSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
 use Drupal;
@@ -12,7 +12,7 @@ use Drupal;
 /**
  * Monitors image derivate creation errors from dblog.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "image_style_missing",
  *   label = @Translation("Image Missing Style"),
  *   description = @Translation("Monitors image derivate creation errors from database log."),
@@ -22,7 +22,7 @@ use Drupal;
  *
  * Displays image derivate with highest occurrence as message.
  */
-class ImageMissingStyleSensor extends DatabaseAggregatorSensor {
+class ImageMissingStyleSensorPlugin extends DatabaseAggregatorSensorPlugin {
 
   /**
    * The path of the most failed image.
diff --git a/src/Plugin/monitoring/Sensor/PaymentCountSensor.php b/src/Plugin/monitoring/SensorPlugin/PaymentCountSensorPlugin.php
similarity index 71%
rename from src/Plugin/monitoring/Sensor/PaymentCountSensor.php
rename to src/Plugin/monitoring/SensorPlugin/PaymentCountSensorPlugin.php
index f495286..b57b039 100644
--- a/src/Plugin/monitoring/Sensor/PaymentCountSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/PaymentCountSensorPlugin.php
@@ -1,25 +1,25 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\PaymentCountSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\PaymentCountSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\DatabaseAggregatorSensorBase;
+use Drupal\monitoring\SensorPlugin\DatabaseAggregatorSensorPluginBase;
 
 /**
  * Monitors payment count.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "payment_count",
  *   label = @Translation("Payment Count"),
  *   description = @Translation("Monitors the number of successful transactions for payments with effective date."),
  *   addable = TRUE
  * )
  */
-class PaymentCountSensor extends DatabaseAggregatorSensorBase {
+class PaymentCountSensorPlugin extends DatabaseAggregatorSensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/PaymentTurnoverSensor.php b/src/Plugin/monitoring/SensorPlugin/PaymentTurnoverSensorPlugin.php
similarity index 78%
rename from src/Plugin/monitoring/Sensor/PaymentTurnoverSensor.php
rename to src/Plugin/monitoring/SensorPlugin/PaymentTurnoverSensorPlugin.php
index 7bb87de..afabfc2 100644
--- a/src/Plugin/monitoring/Sensor/PaymentTurnoverSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/PaymentTurnoverSensorPlugin.php
@@ -1,13 +1,13 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\SensorPaymentTurnover.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\SensorPaymentTurnover.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\DatabaseAggregatorSensorBase;
+use Drupal\monitoring\SensorPlugin\DatabaseAggregatorSensorPluginBase;
 
 /**
  * Monitors payment turnover stats.
@@ -15,14 +15,14 @@ use Drupal\monitoring\Sensor\DatabaseAggregatorSensorBase;
  * A custom database query is used here instead of entity manager for
  * performance reasons.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "payment_turnover",
  *   label = @Translation("Payment Turnover"),
  *   description = @Translation("Monitors how much money was transferred for payments with effective date."),
  *   addable = TRUE
  * )
  */
-class PaymentTurnoverSensor extends DatabaseAggregatorSensorBase {
+class PaymentTurnoverSensorPlugin extends DatabaseAggregatorSensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/QueueSizeSensor.php b/src/Plugin/monitoring/SensorPlugin/QueueSizeSensorPlugin.php
similarity index 80%
rename from src/Plugin/monitoring/Sensor/QueueSizeSensor.php
rename to src/Plugin/monitoring/SensorPlugin/QueueSizeSensorPlugin.php
index 9e48960..e15ec5b 100644
--- a/src/Plugin/monitoring/Sensor/QueueSizeSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/QueueSizeSensorPlugin.php
@@ -1,20 +1,20 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\QueueSizeSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\QueueSizeSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\ThresholdsSensorBase;
+use Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginBase;
 use Drupal;
 use Drupal\Core\Form\FormStateInterface;
 
 /**
  * Monitors number of items for a given core queue.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "queue_size",
  *   label = @Translation("Queue Size"),
  *   description = @Translation("Monitors number of items for a given core queue."),
@@ -26,7 +26,7 @@ use Drupal\Core\Form\FormStateInterface;
  *
  * @see \DrupalQueue
  */
-class QueueSizeSensor extends ThresholdsSensorBase {
+class QueueSizeSensorPlugin extends ThresholdsSensorPluginBase {
 
   /**
    * Adds UI to select Queue for the sensor.
diff --git a/src/Plugin/monitoring/Sensor/SearchApiUnindexedSensor.php b/src/Plugin/monitoring/SensorPlugin/SearchApiUnindexedSensorPlugin.php
similarity index 74%
rename from src/Plugin/monitoring/Sensor/SearchApiUnindexedSensor.php
rename to src/Plugin/monitoring/SensorPlugin/SearchApiUnindexedSensorPlugin.php
index e1f0d26..a3710ac 100644
--- a/src/Plugin/monitoring/Sensor/SearchApiUnindexedSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/SearchApiUnindexedSensorPlugin.php
@@ -1,19 +1,19 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\SearchApiUnindexedSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\SearchApiUnindexedSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\ThresholdsSensorBase;
+use Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginBase;
 use Drupal\search_api\Entity\Index;
 
 /**
  * Monitors unindexed items for a search api index.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "search_api_unindexed",
  *   label = @Translation("Unindexed Search Items"),
  *   description = @Translation("Monitors unindexed items for a search api index."),
@@ -27,7 +27,7 @@ use Drupal\search_api\Entity\Index;
  *
  * @see search_api_index_status()
  */
-class SearchApiUnindexedSensor extends ThresholdsSensorBase {
+class SearchApiUnindexedSensorPlugin extends ThresholdsSensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/StateValueSensor.php b/src/Plugin/monitoring/SensorPlugin/StateValueSensorPlugin.php
similarity index 76%
rename from src/Plugin/monitoring/Sensor/StateValueSensor.php
rename to src/Plugin/monitoring/SensorPlugin/StateValueSensorPlugin.php
index f2b4b7c..5bac9de 100644
--- a/src/Plugin/monitoring/Sensor/StateValueSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/StateValueSensorPlugin.php
@@ -2,24 +2,24 @@
 
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\StateValueSensor
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\StateValueSensorPlugin
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
-use Drupal\monitoring\Sensor\ValueComparisonSensorBase;
+use Drupal\monitoring\SensorPlugin\ValueComparisonSensorPluginBase;
 
 /**
  * Generic sensor that checks for a state value.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "state_value",
  *   label = @Translation("State Value"),
  *   description = @Translation("Checks for a specific state value."),
  *   addable = FALSE
  * )
  */
-class StateValueSensor extends ValueComparisonSensorBase {
+class StateValueSensorPlugin extends ValueComparisonSensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/UpdateStatusSensor.php b/src/Plugin/monitoring/SensorPlugin/UpdateStatusSensorPlugin.php
similarity index 94%
rename from src/Plugin/monitoring/Sensor/UpdateStatusSensor.php
rename to src/Plugin/monitoring/SensorPlugin/UpdateStatusSensorPlugin.php
index 1b616f5..2794bd3 100644
--- a/src/Plugin/monitoring/Sensor/UpdateStatusSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/UpdateStatusSensorPlugin.php
@@ -1,18 +1,18 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\UpdateStatusSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\UpdateStatusSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
-use Drupal\monitoring\Sensor\SensorBase;
+use Drupal\monitoring\SensorPlugin\SensorPluginBase;
 
 /**
  * Monitors for available updates of Drupal core and installed contrib modules.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "update_status",
  *   label = @Translation("Update status"),
  *   description = @Translation("Monitors for available updates of Drupal core and installed contrib modules."),
@@ -22,7 +22,7 @@ use Drupal\monitoring\Sensor\SensorBase;
  *
  * Based on drupal core update module.
  */
-class UpdateStatusSensor extends SensorBase {
+class UpdateStatusSensorPlugin extends SensorPluginBase {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/monitoring/Sensor/UserFailedLoginsSensor.php b/src/Plugin/monitoring/SensorPlugin/UserFailedLoginsSensorPlugin.php
similarity index 80%
rename from src/Plugin/monitoring/Sensor/UserFailedLoginsSensor.php
rename to src/Plugin/monitoring/SensorPlugin/UserFailedLoginsSensorPlugin.php
index cf620d1..3e550d5 100644
--- a/src/Plugin/monitoring/Sensor/UserFailedLoginsSensor.php
+++ b/src/Plugin/monitoring/SensorPlugin/UserFailedLoginsSensorPlugin.php
@@ -1,18 +1,17 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Plugin\monitoring\Sensor\UserFailedLoginsSensor.
+ * Contains \Drupal\monitoring\Plugin\monitoring\SensorPlugin\UserFailedLoginsSensorPlugin.
  */
 
-namespace Drupal\monitoring\Plugin\monitoring\Sensor;
+namespace Drupal\monitoring\Plugin\monitoring\SensorPlugin;
 
-use Drupal\Core\Database\Query\SelectInterface;
 use Drupal\monitoring\Result\SensorResultInterface;
 
 /**
  * Monitors user failed login from dblog messages.
  *
- * @Sensor(
+ * @SensorPlugin(
  *   id = "user_failed_logins",
  *   label = @Translation("User Failed Logins"),
  *   description = @Translation("Monitors user failed login from dblog messages."),
@@ -21,7 +20,7 @@ use Drupal\monitoring\Result\SensorResultInterface;
  *
  * Helps to identify bots or brute force attacks.
  */
-class UserFailedLoginsSensor extends DatabaseAggregatorSensor {
+class UserFailedLoginsSensorPlugin extends DatabaseAggregatorSensorPlugin {
 
   /**
    * {@inheritdoc}
diff --git a/src/Plugin/rest/resource/MonitoringSensorConfigResource.php b/src/Plugin/rest/resource/MonitoringSensorResource.php
similarity index 93%
rename from src/Plugin/rest/resource/MonitoringSensorConfigResource.php
rename to src/Plugin/rest/resource/MonitoringSensorResource.php
index 05cf084..05d1f2f 100644
--- a/src/Plugin/rest/resource/MonitoringSensorConfigResource.php
+++ b/src/Plugin/rest/resource/MonitoringSensorResource.php
@@ -21,11 +21,11 @@ use Psr\Log\LoggerInterface;
  * Provides a resource for monitoring sensors.
  *
  * @RestResource(
- *   id = "monitoring-sensor-info",
- *   label = @Translation("Monitoring sensor config")
+ *   id = "monitoring-sensor",
+ *   label = @Translation("Monitoring sensors")
  * )
  */
-class MonitoringSensorConfigResource extends ResourceBase {
+class MonitoringSensorResource extends ResourceBase {
 
   /**
    * The sensor manager.
@@ -101,14 +101,14 @@ class MonitoringSensorConfigResource extends ResourceBase {
         throw new NotFoundHttpException($e->getMessage(), $e);
       }
       $response = $sensor_config->getDefinition();
-      $response['uri'] = \Drupal::request()->getUriForPath('/monitoring-sensor-info/' . $sensor_name);
+      $response['uri'] = \Drupal::request()->getUriForPath('/monitoring-sensor/' . $sensor_name);
       return new ResourceResponse($response);
     }
 
     $list = array();
     foreach ($this->sensorManager->getAllSensorConfig() as $sensor_name => $sensor_config) {
       $list[$sensor_name] = $sensor_config->getDefinition();
-      $list[$sensor_name]['uri'] = \Drupal::request()->getUriForPath('/monitoring-sensor-info/' . $sensor_name);
+      $list[$sensor_name]['uri'] = \Drupal::request()->getUriForPath('/monitoring-sensor/' . $sensor_name);
     }
     return new ResourceResponse($list);
   }
diff --git a/src/Plugin/rest/resource/MonitoringSensorResultResource.php b/src/Plugin/rest/resource/MonitoringSensorResultResource.php
index ca069a7..9a7993c 100644
--- a/src/Plugin/rest/resource/MonitoringSensorResultResource.php
+++ b/src/Plugin/rest/resource/MonitoringSensorResultResource.php
@@ -112,8 +112,8 @@ class MonitoringSensorResultResource extends ResourceBase {
         $result = $this->sensorRunner->runSensors($sensor_config);
         $response = $result[$sensor_name]->toArray();
         $response['uri'] = $request->getUriForPath('/monitoring-sensor-result/' . $sensor_name);
-        if ($request->get('expand') == 'sensor_info') {
-          $response['sensor_info'] = $result[$sensor_name]->getSensorConfig()->toArray();
+        if ($request->get('expand') == 'sensor') {
+          $response['sensor'] = $result[$sensor_name]->getSensorConfig()->toArray();
         }
         return new ResourceResponse($response);
       }
@@ -129,8 +129,8 @@ class MonitoringSensorResultResource extends ResourceBase {
       foreach ($this->sensorRunner->runSensors() as $sensor_name => $result) {
         $list[$sensor_name] = $result->toArray();
         $list[$sensor_name]['uri'] = $request->getUriForPath('/monitoring-sensor-result/' . $sensor_name);
-        if ($request->get('expand') == 'sensor_info') {
-          $list[$sensor_name]['sensor_info'] = $result->getSensorConfig()->toArray();
+        if ($request->get('expand') == 'sensor') {
+          $list[$sensor_name]['sensor'] = $result->getSensorConfig()->toArray();
         }
       }
       return new ResourceResponse($list);
diff --git a/src/Result/SensorResult.php b/src/Result/SensorResult.php
index 10fbbb9..3a11aad 100644
--- a/src/Result/SensorResult.php
+++ b/src/Result/SensorResult.php
@@ -501,5 +501,4 @@ class SensorResult implements SensorResultInterface {
     return $this->verboseOutput;
   }
 
-
 }
diff --git a/src/Result/SensorResultInterface.php b/src/Result/SensorResultInterface.php
index 8cfb749..24f4486 100644
--- a/src/Result/SensorResultInterface.php
+++ b/src/Result/SensorResultInterface.php
@@ -120,7 +120,7 @@ interface SensorResultInterface {
    *
    * If the status is STATUS_UNKNOWN, this will attempt to set the status
    * based on expected value and threshold configurations. See
-   * \Drupal\monitoring\Sensor\SensorInterface::runSensor() for details.
+   * \Drupal\monitoring\SensorPlugin\SensorPluginInterface::runSensor() for details.
    *
    * @throws \Drupal\monitoring\Sensor\SensorCompilationException
    *   Thrown if an error occurs during the sensor result compilation.
@@ -187,7 +187,7 @@ interface SensorResultInterface {
    * Sets sensor execution time in ms.
    *
    * @param float $time
-   *   Sensor execution time in ms
+   *   Sensor execution time in ms.
    */
   public function setExecutionTime($time);
 
diff --git a/src/Sensor/ThresholdsSensorInterface.php b/src/Sensor/ThresholdsSensorInterface.php
deleted file mode 100644
index ea82c48..0000000
--- a/src/Sensor/ThresholdsSensorInterface.php
+++ /dev/null
@@ -1,16 +0,0 @@
-<?php
-/**
- * @file
- * Contains \Drupal\monitoring\Sensor\SensorThresholdsInterface.
- */
-
-namespace Drupal\monitoring\Sensor;
-
-/**
- * Interface for a sensor with thresholds.
- *
- * Sensors implementing this interface can have thresholds.
- */
-interface ThresholdsSensorInterface {
-
-}
diff --git a/src/Sensor/DatabaseAggregatorSensorBase.php b/src/SensorPlugin/DatabaseAggregatorSensorPluginBase.php
similarity index 95%
rename from src/Sensor/DatabaseAggregatorSensorBase.php
rename to src/SensorPlugin/DatabaseAggregatorSensorPluginBase.php
index 57018c7..e10c7d7 100644
--- a/src/Sensor/DatabaseAggregatorSensorBase.php
+++ b/src/SensorPlugin/DatabaseAggregatorSensorPluginBase.php
@@ -1,15 +1,14 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Sensor\DatabaseAggregatorSensorBase.
+ * Contains \Drupal\monitoring\SensorPlugin\DatabaseAggregatorSensorPluginBase.
  */
 
-namespace Drupal\monitoring\Sensor;
+namespace Drupal\monitoring\SensorPlugin;
 
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\monitoring\Entity\SensorConfig;
 use Drupal\monitoring\Form\SensorForm;
-use Drupal\monitoring\Sensor\ThresholdsSensorBase;
 
 /**
  * Base class for database aggregator sensors.
@@ -25,7 +24,7 @@ use Drupal\monitoring\Sensor\ThresholdsSensorBase;
  *
  * Adds time interval to sensor settings form.
  */
-abstract class DatabaseAggregatorSensorBase extends ThresholdsSensorBase {
+abstract class DatabaseAggregatorSensorPluginBase extends ThresholdsSensorPluginBase {
 
   /**
    * Gets conditions to be used in the select query.
diff --git a/src/Sensor/SensorExtendedInfoInterface.php b/src/SensorPlugin/ExtendedInfoSensorPluginInterface.php
similarity index 72%
rename from src/Sensor/SensorExtendedInfoInterface.php
rename to src/SensorPlugin/ExtendedInfoSensorPluginInterface.php
index 86e39e4..f2d24f7 100644
--- a/src/Sensor/SensorExtendedInfoInterface.php
+++ b/src/SensorPlugin/ExtendedInfoSensorPluginInterface.php
@@ -1,10 +1,10 @@
 <?php
 /**
  * @file
- * Sensor Extended Info interface.
+ * Contains \Drupal\monitoring\SensorPlugin\ExtendedInfoSensorPluginInterface.
  */
 
-namespace Drupal\monitoring\Sensor;
+namespace Drupal\monitoring\SensorPlugin;
 
 use Drupal\monitoring\Result\SensorResultInterface;
 
@@ -13,7 +13,7 @@ use Drupal\monitoring\Result\SensorResultInterface;
  *
  * Implemented by sensors with verbose information.
  */
-interface SensorExtendedInfoInterface {
+interface ExtendedInfoSensorPluginInterface {
 
   /**
    * Provide additional info about sensor call.
diff --git a/src/Sensor/ThresholdsSensorBase.php b/src/SensorPlugin/ThresholdsSensorPluginBase.php
similarity index 96%
rename from src/Sensor/ThresholdsSensorBase.php
rename to src/SensorPlugin/ThresholdsSensorPluginBase.php
index 27ecf0c..ac814f4 100644
--- a/src/Sensor/ThresholdsSensorBase.php
+++ b/src/SensorPlugin/ThresholdsSensorPluginBase.php
@@ -1,20 +1,20 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Sensor\ThresholdsSensorBase.
+ * Contains \Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginBase.
  */
 
-namespace Drupal\monitoring\Sensor;
+namespace Drupal\monitoring\SensorPlugin;
 
 use Drupal\Core\Form\FormStateInterface;
 
 /**
- * Abstract class providing configuration form for Sensor with thresholds.
+ * Abstract class with configuration form for Sensor plugins with thresholds.
  *
  * Sensors may provide thresholds that apply by default.
  * Threshold values are validated for sequence.
  */
-abstract class ThresholdsSensorBase extends SensorBase implements ThresholdsSensorInterface {
+abstract class ThresholdsSensorPluginBase extends SensorPluginBase implements ThresholdsSensorPluginInterface {
 
   /**
    * {@inheritdoc}
@@ -24,7 +24,7 @@ abstract class ThresholdsSensorBase extends SensorBase implements ThresholdsSens
 
     $form['thresholds'] = array(
       '#type' => 'fieldset',
-      '#title' => t('Sensor thresholds'),
+      '#title' => t('SensorPlugin thresholds'),
       '#description' => t('Here you can set limit values that switch the sensor to a given status.'),
       '#prefix' => '<div id="monitoring-sensor-thresholds">',
       '#suffix' => '</div>',
diff --git a/src/SensorPlugin/ThresholdsSensorPluginInterface.php b/src/SensorPlugin/ThresholdsSensorPluginInterface.php
new file mode 100644
index 0000000..7a19e92
--- /dev/null
+++ b/src/SensorPlugin/ThresholdsSensorPluginInterface.php
@@ -0,0 +1,16 @@
+<?php
+/**
+ * @file
+ * Contains \Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginInterface.
+ */
+
+namespace Drupal\monitoring\SensorPlugin;
+
+/**
+ * Interface for a sensor with thresholds.
+ *
+ * Sensors implementing this interface can have thresholds.
+ */
+interface ThresholdsSensorPluginInterface {
+
+}
diff --git a/src/Sensor/ValueComparisonSensorBase.php b/src/SensorPlugin/ValueComparisonSensorPluginBase.php
similarity index 91%
rename from src/Sensor/ValueComparisonSensorBase.php
rename to src/SensorPlugin/ValueComparisonSensorPluginBase.php
index 9fe727e..a466175 100644
--- a/src/Sensor/ValueComparisonSensorBase.php
+++ b/src/SensorPlugin/ValueComparisonSensorPluginBase.php
@@ -2,10 +2,10 @@
 
 /**
  * @file
- * Contains \Drupal\monitoring\Sensor\ValueComparisonSensorBase
+ * Contains \Drupal\monitoring\SensorPlugin\ValueComparisonSensorPluginBase
  */
 
-namespace Drupal\monitoring\Sensor;
+namespace Drupal\monitoring\SensorPlugin;
 
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\monitoring\Result\SensorResultInterface;
@@ -17,7 +17,7 @@ use Drupal\monitoring\Result\SensorResultInterface;
  * value will be compared to. You can prepopulate this offset with initial
  * value that will be used as the expected one on the sensor enable.
  */
-abstract class ValueComparisonSensorBase extends SensorBase {
+abstract class ValueComparisonSensorPluginBase extends SensorPluginBase {
 
   /**
    * Gets the value description that will be shown in the settings form.
diff --git a/src/SensorRunner.php b/src/SensorRunner.php
index 057164a..3282648 100644
--- a/src/SensorRunner.php
+++ b/src/SensorRunner.php
@@ -13,8 +13,8 @@ use Drupal\Core\Config\ConfigFactoryInterface;
 use Drupal\monitoring\Result\SensorResultInterface;
 use Drupal\monitoring\Sensor\DisabledSensorException;
 use Drupal\monitoring\Entity\SensorConfig;
-use Drupal;
 use Drupal\monitoring\Sensor\SensorManager;
+use Drupal\monitoring\SensorPlugin\ExtendedInfoSensorPluginInterface;
 
 /**
  * Instantiate and run requested sensors.
@@ -103,7 +103,7 @@ class SensorRunner {
   }
 
   /**
-   * Runs the defined sensableors.
+   * Runs the defined sensors.
    *
    * @param \Drupal\monitoring\Entity\SensorConfig[] $sensors_config_all
    *   List of sensor config object that we want to run.
@@ -185,6 +185,7 @@ class SensorRunner {
 
       // Capture verbose output if requested and if we are able to do so.
       if ($this->verbose && $sensor_config->isExtendedInfo()) {
+        /** @var ExtendedInfoSensorPluginInterface $sensor */
         $result->setVerboseOutput($sensor->resultVerbose($result));
       }
 
@@ -243,7 +244,6 @@ class SensorRunner {
   protected function needsLogging($result, $old_status = NULL, $new_status = NULL) {
     $log_activity = $result->getSensorConfig()->getSetting('result_logging', FALSE);
 
-
     // We log if requested or on status change.
     if ($this->config->get('sensor_call_logging') == 'on_request') {
       return $log_activity || ($old_status != $new_status);
diff --git a/src/Tests/MonitoringApiTest.php b/src/Tests/MonitoringApiTest.php
index f928eec..496ce21 100644
--- a/src/Tests/MonitoringApiTest.php
+++ b/src/Tests/MonitoringApiTest.php
@@ -1,7 +1,7 @@
 <?php
 /**
  * @file
- * Contains \MonitoringApiTest.
+ * Contains \Drupal\monitoring\Tests\MonitoringApiTest.
  */
 
 namespace Drupal\monitoring\Tests;
@@ -78,7 +78,6 @@ class MonitoringApiTest extends MonitoringUnitTestBase {
     // Test value type without value label.
     $sensor_config->value_type = 'bool';
     $sensor_config->save();
-    $value_types = monitoring_value_types();
     $this->assertEqual($sensor_config->getValueLabel(), NULL);
     $this->assertFalse($sensor_config->isNumeric());
     $this->assertTrue($sensor_config->isBool());
diff --git a/src/Tests/MonitoringCoreTest.php b/src/Tests/MonitoringCoreTest.php
index 16dff98..6232b5f 100644
--- a/src/Tests/MonitoringCoreTest.php
+++ b/src/Tests/MonitoringCoreTest.php
@@ -1,9 +1,10 @@
 <?php
 /**
  * @file
- * Contains \MonitoringCoreTest.
+ * Contains \Drupal\monitoring\Tests\MonitoringCoreTest.
  */
 namespace Drupal\monitoring\Tests;
+
 use Drupal\Component\Utility\String;
 use Drupal\Component\Utility\Unicode;
 use Drupal\Core\Field\FieldStorageDefinitionInterface;
@@ -37,7 +38,7 @@ class MonitoringCoreTest extends MonitoringTestBase {
    */
   public function testSensors() {
 
-    // ======= CronLastRunAgeSensor tests ======= //
+    // ======= CronLastRunAgeSensorPlugin tests ======= //
 
     $time_shift = (60 * 60 * 24 + 1);
     \Drupal::state()->set('system.cron_last', REQUEST_TIME - $time_shift);
@@ -94,7 +95,7 @@ class MonitoringCoreTest extends MonitoringTestBase {
     $result = $this->runSensor('core_queue_monitoring_test');
     $this->assertEqual($result->getValue(), 2);
 
-    // ======= CoreRequirementsSensor tests ======= //
+    // ======= CoreRequirementsSensorPlugin tests ======= //
 
     // @todo - This should not be necessary after sensor requirements are updated.
     $sensor_config = SensorConfig::create(array(
@@ -189,7 +190,7 @@ class MonitoringCoreTest extends MonitoringTestBase {
     $this->assertEqual($result->getValue(), 101);
     $this->assertTrue($result->isCritical());
 
-    // ======= ImageMissingStyleSensor tests ======= //
+    // ======= ImageMissingStyleSensorPlugin tests ======= //
 
     $file = file_save_data($this->randomMachineName());
     /** @var FileUsageInterface $usage */
@@ -232,7 +233,7 @@ class MonitoringCoreTest extends MonitoringTestBase {
     $result = $this->runSensor('dblog_event_severity_' . $severities[RfcLogLevel::ALERT]);
     $this->assertEqual($result->getValue(), 1);
 
-    // ======= UserFailedLoginsSensor tests ======= //
+    // ======= UserFailedLoginsSensorPlugin tests ======= //
 
     \Drupal::logger('user')->notice('Login attempt failed for %user.', array('%user' => 'user1'));
     \Drupal::logger('user')->notice('Login attempt failed for %user.', array('%user' => 'user1'));
@@ -243,7 +244,7 @@ class MonitoringCoreTest extends MonitoringTestBase {
     $this->assertTrue(strpos($result->getMessage(), 'user1: 2') !== FALSE);
     $this->assertTrue(strpos($result->getMessage(), 'user2: 1') !== FALSE);
 
-    // ======= Sensor user_session_logouts tests ======= //
+    // ======= SensorPlugin user_session_logouts tests ======= //
 
     \Drupal::logger('user')->notice('Session closed for %name.', array('%user' => 'user1'));
     \Drupal::logger('user')->notice('Session closed for %name.', array('%user' => 'user1'));
@@ -253,7 +254,7 @@ class MonitoringCoreTest extends MonitoringTestBase {
     $this->assertEqual($result->getValue(), 3);
     $this->assertEqual($result->getMessage(), '3 logouts in 1 day');
 
-    // ======= GitDirtyTreeSensor tests ======= //
+    // ======= GitDirtyTreeSensorPlugin tests ======= //
 
     // Enable the sensor and set cmd to output something
     $sensor_config = SensorConfig::load('monitoring_git_dirty_tree');
@@ -325,9 +326,9 @@ class MonitoringCoreTest extends MonitoringTestBase {
   }
 
   /**
-   * Tests for DisappearedSensorsSensor.
+   * Tests for DisappearedSensorsSensorPlugin.
    *
-   * We provide a separate test method for the DisappearedSensorsSensor as we
+   * We provide a separate test method for the DisappearedSensorsSensorPlugin as we
    * need to enable and disable additional modules.
    */
   public function testSensorDisappearedSensors() {
@@ -492,7 +493,7 @@ class MonitoringCoreTest extends MonitoringTestBase {
   }
 
   /**
-   * Test cases for EnabledModulesSensor sensor.
+   * Test cases for EnabledModulesSensorPlugin sensor.
    *
    * We use separate test method as we need to enable/disable modules.
    */
diff --git a/src/Tests/MonitoringServicesTest.php b/src/Tests/MonitoringServicesTest.php
index 9b8040e..0215ca1 100644
--- a/src/Tests/MonitoringServicesTest.php
+++ b/src/Tests/MonitoringServicesTest.php
@@ -1,7 +1,7 @@
 <?php
 /**
  * @file
- * Contains \MonitoringServicesTest.
+ * Contains \Drupal\monitoring\Tests\MonitoringServicesTest.
  */
 
 namespace Drupal\monitoring\Tests;
@@ -48,7 +48,7 @@ class MonitoringServicesTest extends RESTTestBase {
     // Enable REST API for monitoring resources.
     $config = \Drupal::config('rest.settings');
     $settings = array(
-      'monitoring-sensor-info' => array(
+      'monitoring-sensor' => array(
         'GET' => array(
           'supported_formats' => array($this->defaultFormat),
           'supported_auth' => $this->defaultAuth,
@@ -65,7 +65,7 @@ class MonitoringServicesTest extends RESTTestBase {
     $config->save();
     $this->rebuildCache();
 
-    $this->servicesAccount = $this->drupalCreateUser(array('restful get monitoring-sensor-info', 'restful get monitoring-sensor-result'));
+    $this->servicesAccount = $this->drupalCreateUser(array('restful get monitoring-sensor', 'restful get monitoring-sensor-result'));
   }
 
   /**
@@ -74,7 +74,7 @@ class MonitoringServicesTest extends RESTTestBase {
   public function testSensorConfig() {
     $this->drupalLogin($this->servicesAccount);
 
-    $response_data = $this->doRequest('monitoring-sensor-info');
+    $response_data = $this->doRequest('monitoring-sensor');
     $this->assertResponse(200);
 
     foreach (monitoring_sensor_manager()->getAllSensorConfig() as $sensor_name => $sensor_config) {
@@ -87,7 +87,7 @@ class MonitoringServicesTest extends RESTTestBase {
       $this->assertEqual($response_data[$sensor_name]['caching_time'], $sensor_config->getCachingTime());
       $this->assertEqual($response_data[$sensor_name]['time_interval'], $sensor_config->getTimeIntervalValue());
       $this->assertEqual($response_data[$sensor_name]['enabled'], $sensor_config->isEnabled());
-      $this->assertEqual($response_data[$sensor_name]['uri'], Url::fromUri('base://monitoring-sensor-info/' . $sensor_config->getName(), array('absolute' => TRUE))->toString());
+      $this->assertEqual($response_data[$sensor_name]['uri'], Url::fromUri('base://monitoring-sensor/' . $sensor_config->getName(), array('absolute' => TRUE))->toString());
 
       if ($sensor_config->isDefiningThresholds()) {
         $this->assertEqual($response_data[$sensor_name]['thresholds'], $sensor_config->getSetting('thresholds'));
@@ -95,11 +95,11 @@ class MonitoringServicesTest extends RESTTestBase {
     }
 
     $sensor_name = 'sensor_that_does_not_exist';
-    $this->doRequest('monitoring-sensor-info/' . $sensor_name);
+    $this->doRequest('monitoring-sensor/' . $sensor_name);
     $this->assertResponse(404);
 
     $sensor_name = 'dblog_event_severity_error';
-    $response_data = $this->doRequest('monitoring-sensor-info/' . $sensor_name);
+    $response_data = $this->doRequest('monitoring-sensor/' . $sensor_name);
     $this->assertResponse(200);
     $sensor_config = SensorConfig::load($sensor_name);
     $this->assertEqual($response_data['sensor'], $sensor_config->getName());
@@ -111,7 +111,7 @@ class MonitoringServicesTest extends RESTTestBase {
     $this->assertEqual($response_data['caching_time'], $sensor_config->getCachingTime());
     $this->assertEqual($response_data['time_interval'], $sensor_config->getTimeIntervalValue());
     $this->assertEqual($response_data['enabled'], $sensor_config->isEnabled());
-    $this->assertEqual($response_data['uri'], Url::fromUri('base://monitoring-sensor-info/' . $sensor_config->getName(), array('absolute' => TRUE))->toString());
+    $this->assertEqual($response_data['uri'], Url::fromUri('base://monitoring-sensor/' . $sensor_config->getName(), array('absolute' => TRUE))->toString());
 
     if ($sensor_config->isDefiningThresholds()) {
       $this->assertEqual($response_data['thresholds'], $sensor_config->getSetting('thresholds'));
@@ -125,10 +125,10 @@ class MonitoringServicesTest extends RESTTestBase {
     $this->drupalLogin($this->servicesAccount);
 
     // Test request for sensor results with expanded sensor config.
-    $response_data = $this->doRequest('monitoring-sensor-result', array('expand' => 'sensor_info'));
+    $response_data = $this->doRequest('monitoring-sensor-result', array('expand' => 'sensor'));
     $this->assertResponse(200);
     foreach (monitoring_sensor_manager()->getEnabledSensorConfig() as $sensor_name => $sensor_config) {
-      $this->assertTrue(isset($response_data[$sensor_name]['sensor_info']));
+      $this->assertTrue(isset($response_data[$sensor_name]['sensor']));
       $this->assertSensorResult($response_data[$sensor_name], $sensor_config);
     }
 
@@ -137,7 +137,7 @@ class MonitoringServicesTest extends RESTTestBase {
     $response_data = $this->doRequest('monitoring-sensor-result');
     $this->assertResponse(200);
     $sensor_result = reset($response_data);
-    $this->assertTrue(!isset($sensor_result['sensor_info']));
+    $this->assertTrue(!isset($sensor_result['sensor']));
 
     // Make sure the response contains expected count of results.
     $this->assertEqual(count($response_data), count(monitoring_sensor_manager()->getEnabledSensorConfig()));
@@ -154,17 +154,17 @@ class MonitoringServicesTest extends RESTTestBase {
     $this->assertResponse(404);
 
     $sensor_name = 'dblog_event_severity_error';
-    $response_data = $this->doRequest('monitoring-sensor-result/' . $sensor_name, array('expand' => 'sensor_info'));
+    $response_data = $this->doRequest('monitoring-sensor-result/' . $sensor_name, array('expand' => 'sensor'));
     $this->assertResponse(200);
-    // The response must contain the sensor_info.
-    $this->assertTrue(isset($response_data['sensor_info']));
+    // The response must contain the sensor_config.
+    $this->assertTrue(isset($response_data['sensor']));
     $this->assertSensorResult($response_data, SensorConfig::load($sensor_name));
 
     // Try a request without expanding the sensor config and check that it is not
     // present.
     $response_data = $this->doRequest('monitoring-sensor-result/' . $sensor_name);
     $this->assertResponse(200);
-    $this->assertTrue(!isset($response_data['sensor_info']));
+    $this->assertTrue(!isset($response_data['sensor']));
   }
 
   /**
@@ -173,7 +173,7 @@ class MonitoringServicesTest extends RESTTestBase {
    * @param array $response_result
    *   Result received via response.
    * @param \Drupal\monitoring\Entity\SensorConfig $sensor_config
-   *   Sensor config for which we have the result.
+   *   SensorPlugin config for which we have the result.
    */
   protected function assertSensorResult($response_result, SensorConfig $sensor_config) {
     $this->assertEqual($response_result['sensor_name'], $sensor_config->getName());
@@ -195,8 +195,8 @@ class MonitoringServicesTest extends RESTTestBase {
       $this->assertEqual($response_result['execution_time'], $result->getExecutionTime());
     }
 
-    if (isset($response_result['sensor_info'])) {
-      $this->assertEqual($response_result['sensor_info'], $sensor_config->toArray());
+    if (isset($response_result['sensor'])) {
+      $this->assertEqual($response_result['sensor'], $sensor_config->toArray());
     }
   }
 
diff --git a/src/Tests/MonitoringUITest.php b/src/Tests/MonitoringUITest.php
index 33bd380..5bfecbe 100644
--- a/src/Tests/MonitoringUITest.php
+++ b/src/Tests/MonitoringUITest.php
@@ -1,14 +1,13 @@
 <?php
 /**
  * @file
- * Contains \MonitoringUITest.
+ * Contains \Drupal\monitoring\Tests\MonitoringUITest.
  */
 
 namespace Drupal\monitoring\Tests;
 
 use Drupal\Component\Utility\String;
 use Drupal\monitoring\Entity\SensorConfig;
-use Drupal\monitoring\SensorRunner;
 
 /**
  * Tests for the Monitoring UI.
diff --git a/src/Tests/MonitoringUnitTestBase.php b/src/Tests/MonitoringUnitTestBase.php
index 9ebdbcd..9d3a730 100644
--- a/src/Tests/MonitoringUnitTestBase.php
+++ b/src/Tests/MonitoringUnitTestBase.php
@@ -6,12 +6,12 @@
 
 namespace Drupal\monitoring\Tests;
 
-use Drupal\simpletest\DrupalUnitTestBase;
+use Drupal\simpletest\KernelTestBase;
 
 /**
  * Base class for all monitoring tests.
  */
-abstract class MonitoringUnitTestBase extends DrupalUnitTestBase {
+abstract class MonitoringUnitTestBase extends KernelTestBase {
 
   /**
    * Modules to enable.

diff --git a/src/Annotation/Sensor.php b/src/Annotation/SensorPlugin.php
similarity index 79%
rename from src/Annotation/Sensor.php
rename to src/Annotation/SensorPlugin.php
index 19e8660..f09637d 100644
--- a/src/Annotation/Sensor.php
+++ b/src/Annotation/SensorPlugin.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\monitoring\Annotation\Sensor.
+ * Contains \Drupal\monitoring\Annotation\SensorPlugin.
  */
 
 namespace Drupal\monitoring\Annotation;
@@ -10,11 +10,11 @@ namespace Drupal\monitoring\Annotation;
 use Drupal\Component\Annotation\Plugin;
 
 /**
  * Defines Sensor annotation object for reference by Sensor Plugins.
  *
  * @Annotation
  */
-class Sensor extends Plugin {
+class SensorPlugin extends Plugin {
 
    /**
    * The plugin ID.
@@ -10,11 +10,11 @@ namespace Drupal\monitoring\Annotation;
 
 /**
- * Defines Sensor annotation object for reference by Sensor Plugins.
+ * Defines SensorPlugin annotation object for reference by SensorPlugin Plugins.
  *
  * @Annotation
diff --git a/src/Entity/SensorConfig.php b/src/Entity/SensorConfig.php
index 93bc990..85cd72c 100644
--- a/src/Entity/SensorConfig.php
+++ b/src/Entity/SensorConfig.php
@@ -14,6 +14,7 @@ use Drupal\Core\Entity\EntityStorageInterface;
  * Represents a sensor config entity class.
  *
  * @todo more
+ *
  * @ConfigEntityType(
  *   id = "monitoring_sensor_config",
  *   label = @Translation("Monitoring Sensor"),
@@ -121,11 +122,11 @@ class SensorConfig extends ConfigEntityBase {
   public $status = TRUE;
 
   /**
-   * The sensor ID.
+   * Gets Sensor ID.
    *
-   * @var string
+   * @return string
+   *   Sensor ID.
    */
-
   public function getName() {
     return $this->id;
   }
@@ -155,10 +156,10 @@ class SensorConfig extends ConfigEntityBase {
   }
 
   /**
    * Gets sensor class.
    *
    * @return string
-   *   Sensor class
+   *   SensorPlugin class
    */
   public function getSensorClass() {
     $definition = monitoring_sensor_manager()->getDefinition($this->sensor_id);
@@ -168,11 +169,11 @@ class SensorConfig extends ConfigEntityBase {
   /**
    * Gets the sensor plugin.
    *
-   * @return \Drupal\monitoring\Sensor\SensorInterface
+   * @return \Drupal\monitoring\SensorPlugin\SensorPluginInterface
    *   Instantiated sensor.
    */
   public function getPlugin() {
-    $configuration = array('sensor_info' => $this);
+    $configuration = array('sensor_config' => $this);
     $sensor = monitoring_sensor_manager()->createInstance($this->sensor_id, $configuration);
     return $sensor;
   }
@@ -341,7 +342,7 @@ class SensorConfig extends ConfigEntityBase {
    * @return bool
    */
   public function isExtendedInfo() {
-    return in_array('Drupal\monitoring\Sensor\SensorExtendedInfoInterface', class_implements($this->getSensorClass()));
+    return in_array('Drupal\monitoring\SensorPlugin\ExtendedInfoSensorPluginInterface', class_implements($this->getSensorClass()));
   }
 
   /**
@@ -350,7 +351,7 @@ class SensorConfig extends ConfigEntityBase {
    * @return bool
    */
   public function isDefiningThresholds() {
-    return in_array('Drupal\monitoring\Sensor\ThresholdsSensorInterface', class_implements($this->getSensorClass()));
+    return in_array('Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginInterface', class_implements($this->getSensorClass()));
   }
 
   /**
@@ -383,6 +384,10 @@ class SensorConfig extends ConfigEntityBase {
    * {@inheritdoc}
    */
   public static function sort(ConfigEntityInterface $a, ConfigEntityInterface $b) {
+    /**
+     * @var SensorConfig $a
+     * @var SensorConfig $b
+     */
     // Checks whether both labels and categories are equal.
     if ($a->getLabel() == $b->getLabel() && $a->getCategory() == $b->getCategory()) {
       return 0;
@@ -155,10 +156,10 @@ class SensorConfig extends ConfigEntityBase {
 
   /**
-   * Gets sensor class.
+   * Gets sensor plugin class.
    *
    * @return string
diff --git a/src/Form/SensorForm.php b/src/Form/SensorForm.php
index 28ae259..3871f46 100644
--- a/src/Form/SensorForm.php
+++ b/src/Form/SensorForm.php
@@ -10,8 +10,8 @@ use Drupal\Core\Entity\EntityForm;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Url;
 use Drupal\monitoring\Entity\SensorConfig;
-use Drupal\monitoring\Sensor\SensorBase;
-use Drupal\monitoring\Sensor\SensorInterface;
+use Drupal\monitoring\SensorPlugin\SensorPluginBase;
+use Drupal\monitoring\SensorPlugin\SensorPluginInterface;
 
 /**
  * Sensor settings form controller.
@@ -121,6 +121,7 @@ class SensorForm extends EntityForm {
       );
     }
 
+    $value_types = [];
     foreach (monitoring_value_types() as $value_type => $info) {
       $value_types[$value_type] = $info['label'];
     }
@@ -142,7 +143,7 @@ class SensorForm extends EntityForm {
     );
 
     if (isset($sensor_config->sensor_id) && $sensor = $sensor_config->getPlugin()) {
-      /** @var SensorBase $sensor */
+      /** @var SensorPluginBase $sensor */
       $form['settings'] = array(
         '#type' => 'details',
         '#open' => TRUE,
@@ -200,10 +201,10 @@ class SensorForm extends EntityForm {
 
     /* @var SensorConfig $sensor_config */
     $sensor_config = $this->entity;
-    /** @var SensorInterface $sensor */
+    /** @var SensorPluginInterface $sensor */
     if ($sensor_config->isNew()) {
       $plugin = $form_state->getValue('sensor_id');
-      $sensor = monitoring_sensor_manager()->createInstance($plugin, array('sensor_info' => $this->entity));
+      $sensor = monitoring_sensor_manager()->createInstance($plugin, array('sensor_config' => $this->entity));
     }
     else {
       $sensor = $sensor_config->getPlugin();
@@ -220,7 +221,7 @@ class SensorForm extends EntityForm {
 
     /** @var SensorConfig $sensor_config */
     $sensor_config = $this->entity;
-    /** @var SensorInterface $sensor */
+    /** @var SensorPluginInterface $sensor */
     $sensor = $sensor_config->getPlugin();
 
     $sensor->submitConfigurationForm($form, $form_state);
@@ -233,14 +234,14 @@ class SensorForm extends EntityForm {
     parent::save($form, $form_state);
 
     $form_state->setRedirectUrl(new Url('monitoring.sensors_overview_settings'));
-    drupal_set_message($this->t('Sensor settings saved.'));
+    drupal_set_message($this->t('SensorPlugin settings saved.'));
   }
 
   /**
    * Settings form page title callback.
    *
    * @param SensorConfig $monitoring_sensor_config
    *   The Sensor config.
    *
    * @return string
    */
@@ -233,14 +234,14 @@ class SensorForm extends EntityForm {
    *
    * @param SensorConfig $monitoring_sensor_config
-   *   The Sensor config.
+   *   The SensorPlugin config.
    *
    * @return string
diff --git a/src/Sensor/SensorManager.php b/src/Sensor/SensorManager.php
index 86008a4..957f789 100644
--- a/src/Sensor/SensorManager.php
+++ b/src/Sensor/SensorManager.php
@@ -6,11 +6,9 @@
 
 namespace Drupal\monitoring\Sensor;
 
-use Drupal\Component\Utility\NestedArray;
 use Drupal\Component\Utility\String;
 use Drupal\Core\Config\ConfigFactoryInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
-use Drupal\monitoring\SensorRunner;
 use Drupal\Core\Plugin\DefaultPluginManager;
 use Drupal\Core\Cache\CacheBackendInterface;
 use Drupal\monitoring\Entity\SensorConfig;
@@ -56,7 +54,7 @@ class SensorManager extends DefaultPluginManager {
    *   The module handler to invoke the alter hook with.
    */
   function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler, ConfigFactoryInterface $config) {
-    parent::__construct('Plugin/monitoring/Sensor', $namespaces, $module_handler, '\Drupal\monitoring\Sensor\SensorInterface', 'Drupal\monitoring\Annotation\Sensor');
+    parent::__construct('Plugin/monitoring/SensorPlugin', $namespaces, $module_handler, '\Drupal\monitoring\SensorPlugin\SensorPluginInterface', 'Drupal\monitoring\Annotation\SensorPlugin');
     $this->alterInfo('block');
     $this->setCacheBackend($cache_backend, 'monitoring_sensor_plugins');
     $this->config = $config;
@@ -66,13 +64,14 @@ class SensorManager extends DefaultPluginManager {
    * {@inheritdoc}
    */
   public function createInstance($plugin_id, array $configuration = array()) {
-    // Configuration contains sensor_info object. Extracting
+    // Configuration contains sensor_config object. Extracting
     // it to use for sensor object creation.
-    $sensor_config = $configuration['sensor_info'];
+    $sensor_config = $configuration['sensor_config'];
     $definition = $this->getDefinition($plugin_id);
-    // Sensor class from the sensor definition.
+    // SensorPlugin class from the sensor definition.
+    /** @var SensorPluginInterface $class */
     $class = $definition['class'];
     // Creating instance of the sensor. Refer Sensor.php for arguments.
     return $class::create(\Drupal::getContainer(), $sensor_config, $plugin_id, $definition);
   }
 
@@ -137,7 +136,7 @@ class SensorManager extends DefaultPluginManager {
    * @param bool $enabled
    *   Sensor isEnabled flag.
    *
-   * @return \Drupal\monitoring\Entity\SensorConfig[]
+   * @return \Drupal\monitoring\Entity\SensorConfig[][]
    *   Sensor config.
    */
   public function getSensorConfigByCategories($enabled = TRUE) {
@@ -66,13 +64,14 @@ class SensorManager extends DefaultPluginManager {
     $class = $definition['class'];
-    // Creating instance of the sensor. Refer Sensor.php for arguments.
+    // Creating instance of the sensor. Refer SensorPlugin.php for arguments.
     return $class::create(\Drupal::getContainer(), $sensor_config, $plugin_id, $definition);
   }
diff --git a/src/Sensor/SensorBase.php b/src/SensorPlugin/SensorPluginBase.php
similarity index 89%
rename from src/Sensor/SensorBase.php
rename to src/SensorPlugin/SensorPluginBase.php
index a81533a..392ab69 100644
--- a/src/Sensor/SensorBase.php
+++ b/src/SensorPlugin/SensorPluginBase.php
@@ -1,23 +1,22 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Sensor\SensorBase.
+ * Contains \Drupal\monitoring\SensorPlugin\SensorPluginBase.
  */
 
-namespace Drupal\monitoring\Sensor;
+namespace Drupal\monitoring\SensorPlugin;
 
 use Drupal\Core\Form\FormStateInterface;
-use Drupal\Core\Plugin\PluginFormInterface;
 use Drupal\monitoring\Entity\SensorConfig;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Abstract SensorInterface implementation with common behaviour and will be extended by
  * sensor plugins.
  *
  * @todo more
  */
-abstract class SensorBase implements SensorInterface {
+abstract class SensorPluginBase implements SensorPluginInterface {
 
   /**
    * Current sensor config object.
@@ -45,7 +44,7 @@ abstract class SensorBase implements SensorInterface {
    * Instantiates a sensor object.
    *
    * @param SensorConfig $sensor_config
    *   Sensor config object.
    * @param string $plugin_id
    *   The plugin_id for the plugin instance.
    * @param mixed $plugin_definition
@@ -1,23 +1,22 @@
 
 /**
- * Abstract SensorInterface implementation with common behaviour and will be extended by
+ * Abstract SensorPluginInterface implementation with common behaviour and will be extended by
  * sensor plugins.
  *
@@ -45,7 +44,7 @@ abstract class SensorBase implements SensorInterface {
    *
    * @param SensorConfig $sensor_config
-   *   Sensor config object.
+   *   SensorPlugin config object.
    * @param string $plugin_id
    *   The plugin_id for the plugin instance.
diff --git a/src/Sensor/SensorInterface.php b/src/SensorPlugin/SensorPluginInterface.php
similarity index 89%
rename from src/Sensor/SensorInterface.php
rename to src/SensorPlugin/SensorPluginInterface.php
index 2ee2b71..59106ed 100644
--- a/src/Sensor/SensorInterface.php
+++ b/src/SensorPlugin/SensorPluginInterface.php
@@ -1,10 +1,10 @@
 <?php
 /**
  * @file
- * Contains \Drupal\monitoring\Sensor\SensorInterface.
+ * Contains \Drupal\monitoring\SensorPlugin\SensorPluginInterface.
  */
 
-namespace Drupal\monitoring\Sensor;
+namespace Drupal\monitoring\SensorPlugin;
 
 use Drupal\Core\Plugin\PluginFormInterface;
 use Drupal\monitoring\Entity\SensorConfig;
@@ -17,7 +17,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  *
  * @todo more
  */
-interface SensorInterface extends PluginInspectionInterface, PluginFormInterface {
+interface SensorPluginInterface extends PluginInspectionInterface, PluginFormInterface {
 
   /**
    * Service setter.
@@ -57,9 +57,9 @@ interface SensorInterface extends PluginInspectionInterface, PluginFormInterface
    *  - Set the sensor status to critical, warning, ok, info or unknown with
    *    SensorResultInterface::setStatus(). Defaults to unknown.
    *  - Set the sensor value with SensorResultInterface::setValue(). This can
-   *    be a number or a string. Note that hook_monitoring_sensor_info()
-   *    defaults to numeric. If a sensor does not return a numeric result,
-   *    it must be defined accordingly.
+   *    be a number or a string. Note that value_type defaults to numeric.
+   *    If a sensor does not return a numeric result, it must be defined
+   *    accordingly.
    *  - Set the expected sensor value with SensorResultInterface::setExpectedValue().
    *    When doing so, it is not necessary to set the sensor status explicitly,
    *    as that will happen implicitly. See below.
@@ -77,15 +77,15 @@ interface SensorInterface extends PluginInspectionInterface, PluginFormInterface
    * Sensors with unknown status can either be set based on an expected value or
    * thresholds. If the value does not match the expected value, the status
    * is set to critical. Sensors that support thresholds should either subclass
    * \Drupal\monitoring\Sensor\ThresholdsSensorBase or implement
    * \Drupal\monitoring\ThresholdsSensorInterface and provide their own
    * configuration form.
    *
    * The default sensor message will include information about the sensor value,
    * expected value, thresholds, the configured time interval and additional
    * status messages defined.
    * Provided value labels and value types will be considered for displaying the
-   * sensor value, see hook_monitoring_sensor_info() for their documentation. If
+   * sensor value, see hook_monitoring_sensor() for their documentation. If
    * neither value nor status messages are provided, the message will default to
    * "No value".
    *
@@ -77,15 +77,15 @@ interface SensorInterface extends PluginInspectionInterface, PluginFormInterface
    * thresholds. If the value does not match the expected value, the status
    * is set to critical. Sensors that support thresholds should either subclass
-   * \Drupal\monitoring\Sensor\ThresholdsSensorBase or implement
-   * \Drupal\monitoring\ThresholdsSensorInterface and provide their own
-   * configuration form.
+   * \Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginBase or implement
+   * \Drupal\monitoring\SensorPlugin\ThresholdsSensorPluginInterface and provide
+   * their own configuration form.
    *
    * The default sensor message will include information about the sensor value,